# Llyfrau

Bookmark management using a SQLite database.


## Installing

`llyfrau` supports Python 3.6+ and can be installed using [pipx][pipx]

```
$ pipx install llyfrau
```

[pipx]: https://github.com/pipxproject/pipx
